@@ -21,6 +21,8 @@ use std::sync::Arc;
 
 pub use primes::{Calcit, CalcitErr, CalcitItems};
 
+use crate::util::string::strip_shebang;
+
 pub fn load_core_snapshot() -> Result<snapshot::Snapshot, String> {
   // load core libs
   let bytes = include_bytes!("./cirru/calcit-core.cirru");
@@ -112,7 +114,8 @@ pub fn load_module(path: &str, base_dir: &Path) -> Result<snapshot::Snapshot, St
 
   println!("loading module: {}", fullpath);
 
-  let content = fs::read_to_string(&fullpath).unwrap_or_else(|_| panic!("expected Cirru snapshot {:?}", fullpath));
+  let mut content = fs::read_to_string(&fullpath).unwrap_or_else(|_| panic!("expected Cirru snapshot {:?}", fullpath));
+  strip_shebang(&mut content);
   let data = cirru_edn::parse(&content)?;
   // println!("reading: {}", content);
   let snapshot = snapshot::load_snapshot_data(&data, &fullpath)?;
